import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/responsive/responsive.dart';

class SplitScreen extends StatelessWidget {
  final ImageProvider? backgroundImage;
  final Widget? leftChild;
  final Widget? rightChild;
  final Widget? leftCornerLogoNeutral;
  final Widget? leftCornerLogoColor;
  final Widget? footer;
  final double? footerSize;
  final Color? backgroundColor;
  final double? logoSize;
  final double compactLeftHeight;
  final double compactRightHeight;
  const SplitScreen({
    Key? key,
    required this.compactLeftHeight,
    required this.compactRightHeight,
    this.backgroundImage,
    this.leftChild,
    this.rightChild,
    this.leftCornerLogoNeutral,
    this.leftCornerLogoColor,
    this.footer,
    this.footerSize,
    this.backgroundColor,
    this.logoSize,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Scaffold(
      backgroundColor: backgroundColor ?? defaultBackgroundColor,
      body: SizedBox(
        height: size.height,
        width: size.width,
        child: SingleChildScrollView(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Flex(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisSize: MainAxisSize.min,
                direction: Responsive.isMobile(context)
                    ? Axis.vertical
                    : Axis.horizontal,
                children: Responsive.isMobile(context)
                    ? [
                        Container(
                          height: logoSize ?? 150,
                          color: backgroundColor ?? defaultBackgroundColor,
                          child: Align(
                            alignment: Alignment.topLeft,
                            child: Padding(
                                padding: const EdgeInsets.all(defaultPadding),
                                child: leftCornerLogoColor),
                          ),
                        ),
                        RightChild(
                          rightChild: rightChild,
                          height: Responsive.isMobile(context)
                              ? compactRightHeight
                              : size.height - (footerSize ?? 0),
                        ),
                        LeftChild(
                          leftCornerLogo: leftCornerLogoColor,
                          height: Responsive.isMobile(context)
                              ? compactLeftHeight
                              : size.height - (footerSize ?? 0),
                          leftChild: leftChild,
                          backgroundImage: backgroundImage,
                        ),
                      ]
                    : [
                        LeftChild(
                          leftCornerLogo: leftCornerLogoNeutral,
                          height: size.height - (footerSize ?? 0),
                          leftChild: leftChild,
                          backgroundImage: backgroundImage,
                        ),
                        RightChild(
                          rightChild: rightChild,
                          height: size.height - (footerSize ?? 0),
                        ),
                      ],
              ),
              //const Spacer(),
              footer ?? const SizedBox(),
            ],
          ),
        ),
      ),
    );
  }
}

class LeftChild extends StatelessWidget {
  final ImageProvider? backgroundImage;
  final Widget? leftChild;
  final double height;
  final Widget? leftCornerLogo;

  const LeftChild({
    Key? key,
    required this.height,
    required this.leftCornerLogo,
    required this.backgroundImage,
    required this.leftChild,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Flexible(
      flex: Responsive.isMobile(context) ? 1 : 4,
      child: Container(
        height: height,
        width: Responsive.isMobile(context) ? size.width : size.width / 2,
        decoration: BoxDecoration(
          image: DecorationImage(
            image:
                backgroundImage ?? const AssetImage("assets/covers/cover1.jpg"),
            fit: BoxFit.cover,
          ),
        ),
        child: Stack(
          children: [
            leftChild ?? const SizedBox(),
            !Responsive.isMobile(context)
                ? Align(
                    alignment: Alignment.topLeft,
                    child: Padding(
                      padding: const EdgeInsets.all(defaultPadding),
                      child: leftCornerLogo,
                    ),
                  )
                : const SizedBox(),
          ],
        ),
      ),
    );
  }
}

class RightChild extends StatelessWidget {
  final Widget? rightChild;
  final double height;

  const RightChild({
    Key? key,
    required this.height,
    this.rightChild,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Flexible(
      flex: 4,
      child: SizedBox(
        height: height,
        width: Responsive.isMobile(context) ? size.width : size.width / 2,
        child: !Responsive.isMobile(context)
            ? SingleChildScrollView(
                child: rightChild ?? const SizedBox(),
              )
            : rightChild ?? const SizedBox(),
      ),
    );
  }
}
